@@ -86,7 +86,8 @@ map.poly <- function(database, regions = ".", exact = FALSE,
   list(x = coord$x, y = coord$y, range = coord$range, names = nam)
 }
 
-.map.range <- local( {
+.map.range <-
+local({
    val <- NULL
    function(new) if(!missing(new)) val <<- new else val
 })
@@ -233,13 +234,13 @@ closed.polygon <- function(p) {
   ends <- c(breaks - 1, n)
   x[ends + 1] = x[starts]
   y[ends + 1] = y[starts]
-  x = maps:::insert(x, breaks + 1)
-  y = maps:::insert(y, breaks + 1)
+  x = insert(x, breaks + 1)
+  y = insert(y, breaks + 1)
   list(x = x, y = y)
 }
 insert <- function(x, i, v = NA) {
   # insert v into an array x, at positions i
-  # e.g. maps::insert(1:7, c(2, 5, 8))
+  # e.g. insert(1:7, c(2, 5, 8))
   n = length(x)
   new.n = n + length(i)
   m = logical(new.n)
